# [2.5.7](https://github.com/seriaati/enka-py/compare/v2.5.6..v2.5.7) - 2025-06-30

## Bug Fixes

- Fix issue with HSR backup API - ([7ab7b38](https://github.com/seriaati/enka-py/commit/7ab7b383d863bd3a320098e54c6c26f26f102a8e))
- Make compatible with ZZZ 2.0 - ([2925090](https://github.com/seriaati/enka-py/commit/292509028ee0363845427ad9546e5b595d96726a))
- Fix KeyError in ZZZ calc corrections - ([48e744d](https://github.com/seriaati/enka-py/commit/48e744d0b716b592ad64dbf31db30875e6629424))

## Continuous Integrations

- Remove create release workflow - ([a28f5c2](https://github.com/seriaati/enka-py/commit/a28f5c21091ec5872abd3193460a040b931cc9c3))
- Refine workflow triggers - ([1a0b12d](https://github.com/seriaati/enka-py/commit/1a0b12d468cf8efed4d93466331f10713c3f0a40))

## Documentation

- Update features section in README - ([b6d10bb](https://github.com/seriaati/enka-py/commit/b6d10bbc553df27e3c504f58b68892d97ed8f6fd))
- Update index.md - ([bfcc639](https://github.com/seriaati/enka-py/commit/bfcc6391de3d46d24d68bb8f49b69c5d662534e8))

## Features

- Add rupture stuff - ([ee05122](https://github.com/seriaati/enka-py/commit/ee0512284eea02f958c7de8cd5c614a9f76365d4))
- Add theater_act field to Player model - ([eef6e7c](https://github.com/seriaati/enka-py/commit/eef6e7c0d89d55d157ea16a3249f046a7411f448))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#111](https://github.com/seriaati/enka-py/issues/111)) - ([c1b074e](https://github.com/seriaati/enka-py/commit/c1b074e4c692422a40e2d807210482f4d4c6890e))
- **(deps)** lock file maintenance ([#112](https://github.com/seriaati/enka-py/issues/112)) - ([b86297f](https://github.com/seriaati/enka-py/commit/b86297f77d9d068744668af9e322d6c97535c1d0))
- **(deps)** lock file maintenance ([#113](https://github.com/seriaati/enka-py/issues/113)) - ([fcea27c](https://github.com/seriaati/enka-py/commit/fcea27cef3b302251d739eacdd52fd8dcfbe79ac))
- **(deps)** lock file maintenance ([#114](https://github.com/seriaati/enka-py/issues/114)) - ([ca35d7d](https://github.com/seriaati/enka-py/commit/ca35d7d8e97ef4defd5da779475fcaa93d8273d1))
- **(deps)** lock file maintenance ([#115](https://github.com/seriaati/enka-py/issues/115)) - ([1eee6fb](https://github.com/seriaati/enka-py/commit/1eee6fb5939d66ca8d4c5873a46da48cd19f3b11))

## Tests

- Add rupture character test - ([3cc57fc](https://github.com/seriaati/enka-py/commit/3cc57fcf8688fd72c5a8f7e8239a421328064255))

